# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`iib_install`](#iib_install): See the file "LICENSE" for the full license governing this code.  Unused top level class

### Defined types

* [`iib_install::autostart`](#iib_installautostart): This defined type makes sure the specfied IIB broker is automaticaly started at system start.
* [`iib_install::installiib`](#iib_installinstalliib): The defined type `iib_install::installiib` is a convenience type that allows you to install a specific version of the IBM Information Bus (IIB) software on your system.
* [`iib_install::os`](#iib_installos): The `iib_install::os` defined type is a convenience type for adding IIB os users to the system.
* [`iib_install::software`](#iib_installsoftware): This defined type install's specified version of the the IIB software in the specified folder.
* [`iib_install::software::iib6_unpack`](#iib_installsoftwareiib6_unpack): See the file "LICENSE" for the full license governing this code.   IIB 6 and 7 contain a zip in a tar. This class takes care of untarring the

### Resource types

* [`iib_install`](#iib_install): Setup the IIB installer.

### Tasks

* [`restart`](#restart): Restart the specified IIB Broker on the specified node
* [`start`](#start): Startup the specified IIB Broker on the specified node
* [`status`](#status): Fetch the status of the specified IIB Broker on the specified node
* [`stop`](#stop): Shutdown the specified IIB Broker on the specified node

## Classes

### <a name="iib_install"></a>`iib_install`

See the file "LICENSE" for the full license governing this code.

Unused top level class

## Defined types

### <a name="iib_installautostart"></a>`iib_install::autostart`

See the file "LICENSE" for the full license governing this code.

++--++

iib_install::autostart

Here is an example on how to use it:

``` puppet
iib_install::autostart { 'IIBBROKER1':
  ensure       => 'present',
  path         => '/etc/systemd/system',
  service_name => 'iib@',
  install_root => '/opt/IBM',
  iib_version  => '10.0.0.9',
  iib_user     => 'iibadmin',
  iib_group    => 'mqbrkrs',
}
```

--++--

#### Parameters

The following parameters are available in the `iib_install::autostart` defined type:

* [`ensure`](#ensure)
* [`path`](#path)
* [`service_name`](#service_name)
* [`install_root`](#install_root)
* [`iib_version`](#iib_version)
* [`iib_user`](#iib_user)
* [`iib_group`](#iib_group)

##### <a name="ensure"></a>`ensure`

Data type: `Enum['present', 'absent']`

Tells if you want to make sure the broker is either there or not.
This property has twho possible values `present`, which makes sure the broker autostart is present, or `absent` which makes sure there is no autostart beeing applied to this broker.
Here is an example on how to use it:
```puppet
iib_install::autostart { 'IIBBROKER1':
  ...
  ensure       => 'present',
  ...
}
```

Default value: `'present'`

##### <a name="path"></a>`path`

Data type: `String`

Allows you to specify the path where the unit-file will be placed.
Here is an example on how to use this:
``` puppet
iib_install::autostart{'IIBBROKER1':
  ...
  path         => '/etc/mysystemd/system',
  ...
}
```
The default value is `/etc/systemd/system'.

Default value: `lookup('iib_install::autostart::path')`

##### <a name="service_name"></a>`service_name`

Data type: `String`

Allows you to specfy the name of the service.
Here is an example on how to use this:
``` puppet
iib_install::autostart{'IIBBROKER1':
  ...
  service_name => 'my_iib,
  ...
}
```
The default value is : `"iib@$broker_name`.

Default value: `lookup('iib_install::autostart::service_name')`

##### <a name="install_root"></a>`install_root`

Data type: `String`

Specfies the base path where the software used for the broker, is located,
Together with the `iib_version` parameter, this makes the full-path.
``` puppet
iib_install::autostart { 'IIBBROKER1':
  ...
  install_root => '/opt/IBM',
  ...
}
```

Default value: `lookup('iib_install::autostart::install_root')`

##### <a name="iib_version"></a>`iib_version`

Data type: `String`

Specifies the version of IIB that is used for this autostart.
This parameter is used to construct the path of the software.
Here is an example on how to use it:
``` puppet
iib_install::autostart { 'IIBBROKER1':
  ...
  iib_version  => '10.0.0.9',
  ...
}
```

Default value: `lookup('iib_install::autostart::iib_version')`

##### <a name="iib_user"></a>`iib_user`

Data type: `String`

Allows you to specify the OS user the IIB broker will be started under.
Here is an example on how to use this:
``` puppet
iib_install::autostart{'IIBBROKER1':
  ...
  iib_user      => 'myuser',
  ...
}
```
The default value is `miibadmin` and is correct in most situations.

Default value: `lookup('iib_install::autostart::iib_user')`

##### <a name="iib_group"></a>`iib_group`

Data type: `String`

Allows you to specify the OS group the IIB broker will be started under.
Here is an example on how to use this:
``` puppet
iib_install::autostart{'BROKER1':
  ...
  iib_group     => 'mygroup',
  ...
}
```
The default value is `mqbrkrs` and is correct in most situations.

Default value: `lookup('iib_install::autostart::iib_group')`

### <a name="iib_installinstalliib"></a>`iib_install::installiib`

See the file "LICENSE" for the full license governing this code.

++--++

iib_install::installiib

This defined type has support for installing multiple versions of the IIB software. This feature can help you seamlessly migrate your software from one version of IIB to an other one.

Here is an example on how to use it:

``` puppet
iib_install::installiib {...:
  source_location   => '/software',
  version           => '10.0.0.8',
  iibadmin_password => 'verysecret',
}
```

--++--

#### Parameters

The following parameters are available in the `iib_install::installiib` defined type:

* [`source_location`](#source_location)
* [`version`](#version)
* [`iibadmin_password`](#iibadmin_password)
* [`file_name`](#file_name)

##### <a name="source_location"></a>`source_location`

Data type: `String[1]`

The location of the IIB software.
Here is an example on how to use this:
```puppet
iib_install::... {...:
  ...
  source_location => '/software',
  ...
}
```

##### <a name="version"></a>`version`

Data type: `String[1]`

The version of IIB you want to install.
Here is an example on how to use it:
``` puppet
iib_install::installiib {...:
  ...
  version           => '10.0.0.8',
  ...
}
```

##### <a name="iibadmin_password"></a>`iibadmin_password`

Data type: `Easy_type::Password`

The password to be used for the `iibadmin` user.
The default is `iibadmin`.
Here is an example on how to use it:
``` puppet
iib_install::installiib {...:
  ...
  iibadmin_password => 'verysecret',
  ...
}
```

Default value: `lookup({name => 'iib_install::installiib::iibadmin_password'})`

##### <a name="file_name"></a>`file_name`

Data type: `Optional[String[1]]`



Default value: ``undef``

### <a name="iib_installos"></a>`iib_install::os`

See the file "LICENSE" for the full license governing this code.

++--++

iib_install::os

Using this defined type you can add multiple users to the system.

Here is an example on how to use it:

``` puppet
iib_install::os {'my_iibadmin':
  password => 'verysecret',
}
```

--++--

#### Parameters

The following parameters are available in the `iib_install::os` defined type:

* [`title`](#title)
* [`password`](#password)

##### <a name="title"></a>`title`

The OS user to add to the system and grant access to the MQ groups.
```puppet
iib_install::os {'iibadmin':
  ...
}
```

##### <a name="password"></a>`password`

Data type: `String`

The password to be used for user.
The default is the same as the username.
Here is an example on how to use this:
```puppet
iib_install::os {...:
  ...
  password => 'verysecret',
  ...
}
```

Default value: `$title`

### <a name="iib_installsoftware"></a>`iib_install::software`

See the file "LICENSE" for the full license governing this code.

++--++

iib_install::software

The source zip file from IBM is found at the location specified at `source_location`.

Here is an example on how to use it:

``` puppet
iib_install::software{ '10.0.0.8':
  source_location  => '/software',
  install_root     => '/opt/IBM',
  tmp_dir          => '/mytemp',
  logoutput        => true,
}

```

--++--

#### Parameters

The following parameters are available in the `iib_install::software` defined type:

* [`source_location`](#source_location)
* [`install_root`](#install_root)
* [`tmp_dir`](#tmp_dir)
* [`logoutput`](#logoutput)
* [`file_name`](#file_name)

##### <a name="source_location"></a>`source_location`

Data type: `String[1]`

The location of the IIB software.
Here is an example on how to use this:
```puppet
iib_install::... {...:
  ...
  source_location => '/software',
  ...
}
```

##### <a name="install_root"></a>`install_root`

Data type: `Stdlib::Absolutepath`

The location on the file system where the software will be places.
The default is '/opt/IBM'.
Here is an example on how to use this:
```puppet
iib_install::software {...:
  ...
  install_root => /my_opt/IBM',
  ...
}
```

Default value: `'/opt/IBM'`

##### <a name="tmp_dir"></a>`tmp_dir`

Data type: `Stdlib::Absolutepath`

This defined type uses a temporary directory.
By default this is `\tmp`. If you want to use an other directory for this, you must specify this parameter.
Here is an example on how to use this:
```puppet
iib_install::software {...:
  ...
  tmp_dir => /my_tmp',
  ...
}
```

Default value: `'/tmp'`

##### <a name="logoutput"></a>`logoutput`

Data type: `Variant[Enum['on_failure'], Boolean]`

If you want to see the output of the `exec` resources in the type, you can set this value to `true`.
The default is `on_failure`.
Here is an example on how to use this:
```puppet
iib_install::... {...:
  ...
  logoutput => true,
  ...
}
```

Default value: `'on_failure'`

##### <a name="file_name"></a>`file_name`

Data type: `Optional[String[1]]`



Default value: ``undef``

### <a name="iib_installsoftwareiib6_unpack"></a>`iib_install::software::iib6_unpack`

See the file "LICENSE" for the full license governing this code.


IIB 6 and 7 contain a zip in a tar. This class
takes care of untarring the toplevel tar.gz file_name
and making sure the rest of the puppet code
can handle the result

#### Parameters

The following parameters are available in the `iib_install::software::iib6_unpack` defined type:

* [`tmp_dir`](#tmp_dir)
* [`source_location`](#source_location)

##### <a name="tmp_dir"></a>`tmp_dir`

Data type: `String[1]`



##### <a name="source_location"></a>`source_location`

Data type: `String[1]`



## Resource types

### <a name="iib_install"></a>`iib_install`

Setup the IIB installer.

#### Properties

The following properties are available in the `iib_install` type.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

#### Parameters

The following parameters are available in the `iib_install` type.

* [`provider`](#provider)

##### <a name="provider"></a>`provider`

The specific backend to use for this `iib_install` resource. You will seldom need to specify this --- Puppet will
usually discover the appropriate provider for your platform.

## Tasks

### <a name="restart"></a>`restart`

Restart the specified IIB Broker on the specified node

**Supports noop?** false

#### Parameters

##### `broker_name`

Data type: `Optional[String[1]]`

name of the broker

### <a name="start"></a>`start`

Startup the specified IIB Broker on the specified node

**Supports noop?** false

#### Parameters

##### `broker_name`

Data type: `Optional[String[1]]`

name of the broker

### <a name="status"></a>`status`

Fetch the status of the specified IIB Broker on the specified node

**Supports noop?** false

#### Parameters

##### `broker_name`

Data type: `Optional[String[1]]`

name of the broker

### <a name="stop"></a>`stop`

Shutdown the specified IIB Broker on the specified node

**Supports noop?** false

#### Parameters

##### `broker_name`

Data type: `Optional[String[1]]`

name of the broker

